Citing Aurora
=============

While Aurora is released publicly in a selfless effort to support the development of fusion energy, we do appreciate users pushing our numbers by giving a star to the Aurora Github repo

  https://github.com/fsciortino/aurora

and by citing the following works:

[1] F. Sciortino et al 2020 Nucl. Fusion 60 126014, https://doi.org/10.1088/1741-4326/abae85

    This paper presented the original application of Aurora to infer impurity transport coefficients in Alcator C-Mod plasmas. Here, the code is referred to as `pySTRAHL` (what a terrible name).

[2] R. Dux, 2004, Habilitation Thesis, MPI-IPP. http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.830.8834&rep=rep1&type=pdf

    The work of R. Dux on STRAHL is at the basis of many of the methods adopted by Aurora. While Aurora's code does not depend on STRAHL in any way, it owes to it for laying much of the groundwork. 
